version 18

sysdir set PLUS "C:/Users/wb633983/Documents/gh/RR_WLD_2025_284/AIPI Overperformers PRWP Reproducibility/code/ado"

ssc install wbopendata, replace 
net install schemepack, from("https://raw.githubusercontent.com/asjadnaqvi/stata-schemepack/main/installation/") replace
ssc install shp2dta, replace 
ssc install spmap, replace 
ssc install palettes, replace
ssc install colrspace, replace
ssc install graphfunctions, replace
net install spider, from("https://raw.githubusercontent.com/asjadnaqvi/stata-spider/main/installation/") replace
net install waffle, from("https://raw.githubusercontent.com/asjadnaqvi/stata-waffle/main/installation/") replace
help colorpalette // wesanderson palette
colorpalette GrandBudapest1
net install schemepack, from("https://raw.githubusercontent.com/asjadnaqvi/stata-schemepack/main/installation/") replace
ssc install wbopendata, replace


clear all
set more off

* Set the working directory
cd "C:/Users/wb633983/Documents/gh/RR_WLD_2025_284/AIPI Overperformers PRWP Reproducibility"


* Load AI Preparedness dataset
import excel "rawData/imf-dm-export-20241116.xls", firstrow clear // https://www.imf.org/external/datamapper/datasets/AIPI
rename (AIPreparednessIndexIndex B) (countryname ai_preparedness_index)

/*
drop if _n==1
rename (v1 v2) (countryname ai_preparedness_index)
*/

* Keep only individual countries
keep if !inlist(countryname, "Advanced economies", "Emerging market economies", "Asia and Pacific", "European Union", "Euro area", "Europe")

keep if !inlist(countryname, "North America", "Sub-Saharan Africa (Region)", "ASEAN-5", "Latin America and the Caribbean", "Low-income countries", "Major advanced economies (G7)", "Middle East and Central Asia", "Sub-Saharan Africa (Region) ")

drop if missing(ai_preparedness_index)

* Replace non-standardized country names with standardized versions
replace countryname = "Bahamas" if countryname == "Bahamas, The"
replace countryname = "China" if countryname == "China, People's Republic of"
replace countryname = "Congo (Democratic Republic)" if countryname == "Congo, Dem. Rep. of the"
replace countryname = "Congo (Republic)" if countryname == "Congo, Republic of "
replace countryname = "Ivory Coast" if countryname == "Côte d'Ivoire"
replace countryname = "Gambia" if countryname == "Gambia, The"
replace countryname = "South Korea" if countryname == "Korea, Republic of"
replace countryname = "North Macedonia" if countryname == "North Macedonia "
replace countryname = "South Sudan" if countryname == "South Sudan, Republic of"
replace countryname = "Turkey" if countryname == "Türkiye, Republic of"

* Save it in .dta for now
rename ai_preparedness_index AIPI
label var countryname "Country name"
label var AIPI "AI Preparation Index"
save imf_aipi, replace


********************************************************************************
* Load ECI Trade
{
* Load your dataset
import delimited "rawData/Data-ECI-Trade.csv", clear varnames(1) // https://oec.world/en/rankings/eci/hs6/hs96?tab=ranking

foreach var of varlist _all {
    local label: variable label `var'
    if ("`label'" != "") {
        * If the label starts with a number, prefix it with "var_"
        if regexm("`label'", "^[0-9]") {
            local newname = "var_" + subinstr("`label'", " ", "_", .)
        }
        else {
            local newname = subinstr("`label'", " ", "_", .)
        }
        * Remove any non-alphanumeric characters
        local newname = ustrregexra("`newname'", "[^a-zA-Z0-9_]", "")
        
        * Rename the variable if there are no naming conflicts
        cap rename `var' `newname'
    }
}

* Reshape the data from wide to long format
reshape long var_, i(Country_ID) j(Year)

* Adjust the Year variable to remove any prefix
destring Year, replace

* Rename var_
rename var_ ECI_Trade
label var ECI_Trade "ECI based on exports"


* Save dataset temp
save eci_trade, replace
}

********************************************************************************
* Load ECI Tech
{
* Load your dataset
import delimited "rawData/Data-ECI-Technology.csv", clear varnames(1) // https://oec.world/en/rankings/eci/hs6/hs96?tab=ranking

foreach var of varlist _all {
    local label: variable label `var'
    if ("`label'" != "") {
        * If the label starts with a number, prefix it with "var_"
        if regexm("`label'", "^[0-9]") {
            local newname = "var_" + subinstr("`label'", " ", "_", .)
        }
        else {
            local newname = subinstr("`label'", " ", "_", .)
        }
        * Remove any non-alphanumeric characters
        local newname = ustrregexra("`newname'", "[^a-zA-Z0-9_]", "")
        
        * Rename the variable if there are no naming conflicts
        cap rename `var' `newname'
    }
}

* Reshape the data from wide to long format
reshape long var_, i(Country_ID) j(Year)

* Adjust the Year variable to remove any prefix
destring Year, replace

* Rename var_
rename var_ ECI_Tech
label var ECI_Tech "ECI based on patents"


* Save dataset temp
save eci_tech, replace
}

********************************************************************************
* Load ECI Research
{
* Load your dataset
import delimited "rawData/Data-ECI-Research.csv", clear varnames(1) // https://oec.world/en/rankings/eci/hs6/hs96?tab=ranking

foreach var of varlist _all {
    local label: variable label `var'
    if ("`label'" != "") {
        * If the label starts with a number, prefix it with "var_"
        if regexm("`label'", "^[0-9]") {
            local newname = "var_" + subinstr("`label'", " ", "_", .)
        }
        else {
            local newname = subinstr("`label'", " ", "_", .)
        }
        * Remove any non-alphanumeric characters
        local newname = ustrregexra("`newname'", "[^a-zA-Z0-9_]", "")
        
        * Rename the variable if there are no naming conflicts
        cap rename `var' `newname'
    }
}

* Reshape the data from wide to long format
reshape long var_, i(Country_ID) j(Year)

* Adjust the Year variable to remove any prefix
destring Year, replace

* Rename var_
rename var_ ECI_Res
label var ECI_Res "ECI based on research publications"


* Save dataset temp
save eci_res, replace
}

********************************************************************************
* Merge all ECI Together
{
use eci_trade, clear

merge m:1 Country Year using eci_tech
drop _merge

merge m:1 Country Year using eci_res
drop _merge

order Country
keep if Year>=2021
collapse (mean) ECI_Trade ECI_Tech ECI_Res, by(Country Country_ID)

* Implement a PCA per country, with 2 components max
*a] List of valid indicators
local indicators ECI_Trade ECI_Tech ECI_Res

*b] Standardize the data
foreach var in `indicators' {
    egen z_`var' = std(`var')
}

*c] Perform PCA on standardized indicators
pca z_ECI_Trade /*z_ECI_Tech*/ z_ECI_Res, comp(2) // too many missing values for z_ECI_Tech

predict PC1 // only PC1 has Eigenvalue>50%
drop z_ECI_Trade -z_ECI_Res

gen KH_r= ECI_Trade
label var KH_r "Know-how reduced version"

rename PC1 KH_e
label var KH_e "Know-how extended version"

*d] Normalize to avoid negative values
egen min_KH_r=min(KH_r)
egen min_KH_e=min(KH_e)


gen KH_r_norm = KH_r - min_KH_r + .0001
egen max_KH_r_norm=max(KH_r_norm)

gen KH_e_norm = KH_e - min_KH_e + .0001
egen max_KH_e_norm=max(KH_e_norm)

*e] Optionally scale it between 0 and 1
gen KH_r_scaled = KH_r_norm / max_KH_r_norm
label var KH_r_scaled "ECI reduced version [scaled 0-1]"
drop min_KH_r max_KH_r_norm KH_r_norm

gen KH_e_scaled = KH_e_norm / max_KH_e_norm
label var KH_e_scaled "ECI extended version [scaled 0-1]"
drop min_KH_e max_KH_e_norm KH_e_norm


* Align country names with the AI Preparedness data
replace Country = "Myanmar" if Country == "Burma"
replace Country = "Taiwan Province of China" if Country == "Chinese Taipei"
replace Country = "Congo (Democratic Republic)" if Country == "Democratic Republic of the Congo"
replace Country = "Congo (Republic)" if Country == "Republic of the Congo"
replace Country = "Ivory Coast" if Country == "Cote d'Ivoire"
replace Country = "Czech Republic" if Country == "Czechia"
replace Country = "Hong Kong SAR" if Country == "Hong Kong"
replace Country = "Kyrgyz Republic" if Country == "Kyrgyzstan"
replace Country = "Lao P.D.R." if Country == "Laos"
replace Country = "Russian Federation" if Country == "Russia"
replace Country = "Slovak Republic" if Country == "Slovakia"

* Save dataset temp
rename Country countryname
save eci_consolidated, replace
}

********************************************************************************
* Load Population size, Region & Income Level
{
wbopendata, indicator(SP.POP.TOTL) clear

* keep only individual countries
tab countryname if regionname=="" | regionname=="Aggregates"
drop if regionname=="" | regionname=="Aggregates" 

* keep only the year 2023
sum yr*
drop yr1960-yr2022

* Replace non-standardized country names with standardized versions
replace countryname = "Bahamas" if countryname == "Bahamas, The"
replace countryname = "Ivory Coast" if countryname == "Cote d'Ivoire"
replace countryname = "Congo (Democratic Republic)" if countryname == "Congo, Dem Rep"
replace countryname = "Congo (Republic)" if countryname == "Congo, Rep"
replace countryname = "Egypt" if countryname == "Egypt, Arab Rep"
replace countryname = "Micronesia" if countryname == "Micronesia, Fed Sts"
replace countryname = "Gambia" if countryname == "Gambia, The"
replace countryname = "Hong Kong" if countryname == "Hong Kong SAR, China"
replace countryname = "Iran" if countryname == "Iran, Islamic Rep"
replace countryname = "South Korea" if countryname == "Korea, Rep"
replace countryname = "Macao" if countryname == "Macao SAR, China"
replace countryname = "North Korea" if countryname == "Korea, Dem People's Rep"
replace countryname = "Venezuela" if countryname == "Venezuela, RB"
replace countryname = "Yemen" if countryname == "Yemen, Rep"

replace countryname = "Hong Kong SAR" if countryname =="Hong Kong"
replace countryname = "Lao P.D.R." if countryname =="Lao PDR"
replace countryname = "Macao SAR" if countryname =="Macao"
replace countryname = "North Korea" if countrycode =="PRK"
replace countryname = "Saint Lucia" if countryname =="St Lucia"
replace countryname = "Saint Vincent and the Grenadines" if countryname =="St Vincent and the Grenadines"
replace countryname = "Syria" if countryname =="Syrian Arab Republic"
replace countryname = "São Tomé and Príncipe" if countryname =="Sao Tome and Principe"


* Reshape to long format for years
reshape long yr, i(countrycode countryname indicatorname indicatorcode) j(year)

* Rename the reshaped column for clarity
rename yr value

* Create a sanitized version of indicator names for variable names
gen indicator_clean = strtoname(trim(indicatorcode))

* Get the list of unique sanitized indicator names
levelsof indicator_clean, local(indicators)

* Loop through the sanitized indicator names and create separate columns
foreach ind in `indicators' {
    gen `ind' = value if indicator_clean == "`ind'"
}

* Adjust income level with latest adjustments for FY25: [https://datahelpdesk.worldbank.org/knowledgebase/articles/906519-world-bank-country-and-lending-groups]
tab incomelevel
replace incomelevel="HIC" if countrycode=="ASM"
replace incomelevel="HIC" if countrycode=="BGR"
replace incomelevel="UMC" if countrycode=="DZA"
replace incomelevel="LMC" if countrycode=="GIN"
replace incomelevel="HIC" if countrycode=="GUY"
replace incomelevel="LMC" if countrycode=="HTI"
*replace incomelevel="UMC" if countrycode=="IRN"
replace incomelevel="LMC" if countrycode=="LBN"
replace incomelevel="UMC" if countrycode=="MDA"
replace incomelevel="UMC" if countrycode=="MNG"
replace incomelevel="UMC" if countrycode=="MUS"
*replace incomelevel="HIC" if countrycode=="PLW"
*replace incomelevel="LMC" if countrycode=="PSE"
replace incomelevel="HIC" if countrycode=="RUS"
replace incomelevel="UMC" if countrycode=="SLV"
replace incomelevel="LMC" if countrycode=="TJK"
replace incomelevel="UMC" if countrycode=="UKR"

* Drop unnecessary columns & indicators
drop value indicatorname indicatorcode indicator_clean
drop /*region adminregion*/ adminregion adminregionname /*incomelevel*/ incomelevelname lendingtype lendingtypename year
save wbopendata_pop_temp, replace
}

********************************************************************************
* Consolidate all Data and Run the Scatter Plots
{
	
use imf_aipi, clear

merge 1:1 countryname using eci_consolidated
*tab _merge
drop _merge

merge 1:1 countryname using wbopendata_pop_temp
tab _merge
drop if _merge==2
replace incomelevel="HIC" if Country_ID =="astwn"
replace SP_POP_TOTL=2.34e+07 if Country_ID =="astwn" // https://www.statista.com/statistics/319793/taiwan-population/#:~:text=In%202023%2C%20the%20total%20population,rate%20was%20also%20slightly%20negative.
replace region="EAS" if Country_ID =="astwn"
replace	regionname="East Asia and Pacific" if Country_ID =="astwn"

sort countryname
order countrycode Country_ID countryname region regionname incomelevel
rename (region SP_POP_TOTL) (regioncode pop_size)

drop _merge
save "intData/aipi_eci.dta", replace
use "intData/aipi_eci.dta", clear

**
erase imf_aipi.dta
erase eci_trade.dta 
erase eci_tech.dta 
erase eci_res.dta 
erase eci_consolidated.dta
erase wbopendata_pop_temp.dta
**


* Dissect Country_ID to extract region and country code
gen region = substr(Country_ID, 1, 2)
gen country_code = substr(Country_ID, 3, 3)
gen label = region + " - " + country_code

* Fancy graph schemes

set scheme white_cividis, perm

* Remove missing values for KH_e_scaled and AIPI
drop if missing(KH_e_scaled, AIPI)


* Defining AIPI thresholds 
sum AIPI if incomelevel=="LIC" | incomelevel=="LMC" [aw=pop_size], d // median = 0.4360671, avg= 0.4114878 rounded to 0.4
sum AIPI if incomelevel=="LMC" | incomelevel=="UMC" [aw=pop_size], d // median = 0.4925031, avg= 0.4978606 rounded to 0.5
sum AIPI if incomelevel=="HIC" [aw=pop_size], d // median = 0.7271003, avg= 0.692826 rounded to 0.7


****
*-Whole sample [unweighted]
preserve

* Calculate fitted values and determine overperformers (AIPI >= 0.7 and above the fit line)
regress AIPI KH_e_scaled
predict AIPI_hat if e(sample)
gen overperformer = (AIPI >= 0.7 & AIPI > AIPI_hat)

ttest AIPI == AIPI_hat if overperformer == 0
ttest AIPI == AIPI_hat if overperformer == 1

* Find the range of KH_e_scaled for AIPI >= 0.7
summarize KH_e_scaled if AIPI >= 0.7
local kh_min = r(min)
local kh_max = r(max)

* Create variables to define the rectangle for AIPI >= 0.7
gen y_lower = 0.7
gen y_upper = 0.8


* Calculate the correlation coefficient (r) and R² value, rounded to two decimal places
correlate AIPI KH_e_scaled
/*pwcorr AIPI KH_e_scaled, sig*/
local r = round(r(rho), 0.01)
local r2 = round(e(r2), 0.001)

* Calculate the sample size
count if !missing(KH_e_scaled, AIPI)
local n = r(N)

* Scatterplot with overperformers highlighted, including R² and r in the chart
twoway ///
    (rarea y_lower y_upper KH_e_scaled if KH_e_scaled >= `kh_min' & KH_e_scaled <= `kh_max', color(gs15)) || ///
    (scatter AIPI KH_e_scaled if !overperformer, mcolor(blue%60) msize(small) mlab(country_code) mlabsize(tiny)) || ///
    (scatter AIPI KH_e_scaled if overperformer & country_code != "kor", mcolor(gold%60) msize(small) mlab(country_code) mlabsize(tiny)) || ///
	(scatter AIPI KH_e_scaled if country_code == "kor", mcolor(gold%60) msize(small) mlab(country_code) mlabsize(tiny) mlabposition(12)) || ///
    (lfit AIPI KH_e_scaled, lcolor(red%80)), ///
    ytitle("AI Prepardness Index (IMF, 2023)") ///
	ylabel(0.1(.1).8, angle(0)) ///
    xtitle("Economic Complexity Index [Trade-Research PCA] (OEC, 2021-22)") ///
    /*title("Relationship between ECI and AIPI")*/ ///
    text(0.80 0 "N = `n'" 0.75 0 "R² = 0`r2'" 0.70 0 "r = 0`r'", color(gs6) place(e) size(small)) ///
    legend(order(1 "AIPI≥0.7" 2 "Other Countries" 3 "Overperformers" 5 "Linear Fit Line") pos(6) size(tiny)) /*///
    note("Overperformers are shown in yellow with country labels", size(tiny))*/

graph export "output/Figure 3A.png", replace
restore


****
*-Whole sample [weighted by pop size]
preserve


* Create categories for population size
gen pop_category = .
replace pop_category = 1 if pop_size < 10e6  // Small population (< 10 million)
replace pop_category = 2 if pop_size >= 10e6 & pop_size < 50e6  // Medium population (10 to 50 million)
replace pop_category = 3 if pop_size >= 50e6 & pop_size < 100e6  // Large population (50 to 100 million)
replace pop_category = 4 if pop_size >= 100e6 & pop_size < 300e6  // Very large population (100 to 300 million)
replace pop_category = 5 if pop_size >= 300e6  // Yuuge population (> 300 million)


* Calculate fitted values and determine overperformers (AIPI >= 0.7 and above the fit line)
regress AIPI KH_e_scaled [aw=pop_size]
predict AIPI_hat if e(sample)
gen overperformer = (AIPI >= 0.7 & AIPI > AIPI_hat)

ttest AIPI == AIPI_hat if overperformer == 0 
ttest AIPI == AIPI_hat if overperformer == 1

* Find the range of KH_e_scaled for AIPI >= 0.7
summarize KH_e_scaled if AIPI >= 0.7
local kh_min = r(min)
local kh_max = r(max)

* Create variables to define the rectangle for AIPI >= 0.7
gen y_lower = 0.7
gen y_upper = 0.8


* Calculate the correlation coefficient (r) and R² value, rounded to two decimal places
correlate AIPI KH_e_scaled [aw=pop_size]
/*pwcorr AIPI KH_e_scaled [aw=pop_size], sig */

local r = round(r(rho), 0.01)
local r2 = string(round(e(r2), 0.001), "%9.2f")  // Convert to string with two decimal places

* Calculate the sample size
count if !missing(KH_e_scaled, AIPI)
local n = r(N)

* Scatterplot with overperformers highlighted, including R² and r in the chart
twoway ///
    (rarea y_lower y_upper KH_e_scaled if KH_e_scaled >= `kh_min' & KH_e_scaled <= `kh_max', color(gs15)) || ///
    (scatter AIPI KH_e_scaled if !overperformer & pop_category == 1 , mcolor(blue%60) msize(tiny) mlab(country_code) mlabsize(tiny)) || ///
    (scatter AIPI KH_e_scaled if !overperformer & pop_category == 2 , mcolor(blue%60) msize(small) mlab(country_code) mlabsize(tiny)) || ///
    (scatter AIPI KH_e_scaled if !overperformer & pop_category == 3 , mcolor(blue%60) msize(medium) mlab(country_code) mlabsize(tiny)) || ///
    (scatter AIPI KH_e_scaled if !overperformer & pop_category == 4, mcolor(blue%60) msize(large) mlab(country_code) mlabsize(tiny)) || ///
	(scatter AIPI KH_e_scaled if !overperformer & pop_category == 5, mcolor(blue%60) msize(huge) mlab(country_code) mlabsize(tiny)) || ///
    (scatter AIPI KH_e_scaled if overperformer & pop_category == 1 & country_code != "kor", mcolor(gold%60) msize(tiny) mlab(country_code) mlabsize(tiny)) || ///
    (scatter AIPI KH_e_scaled if overperformer & pop_category == 2 & country_code != "kor", mcolor(gold%60) msize(small) mlab(country_code) mlabsize(tiny)) || ///
    (scatter AIPI KH_e_scaled if overperformer & pop_category == 3 & country_code != "kor", mcolor(gold%60) msize(medium) mlab(country_code) mlabsize(tiny)) || ///
    (scatter AIPI KH_e_scaled if overperformer & pop_category == 4 & country_code != "kor", mcolor(gold%60) msize(large) mlab(country_code) mlabsize(tiny)) || ///
	(scatter AIPI KH_e_scaled if overperformer & pop_category == 5 & country_code != "kor", mcolor(gold%60) msize(huge) mlab(country_code) mlabsize(tiny)) || ///
    (scatter AIPI KH_e_scaled if country_code == "kor", mcolor(gold%60) msize(medium) mlab(country_code) mlabsize(tiny) mlabposition(12)) || ///
    (lfit AIPI KH_e_scaled [aw=pop_size], lcolor(red%80)), ///
    ytitle("AI Prepardness Index (IMF, 2023)") ///
	ylabel(0.1(.1).8, angle(0)) ///
    xtitle("Economic Complexity Index [Trade-Research PCA] (OEC, 2021-22)") ///
    /*title("Relationship between ECI and AIPI")*/ ///
    text(0.80 0 "N = `n'" 0.75 0 "R² = `r2'" 0.70 0 "r = 0`r'", color(gs6) place(e) size(small)) ///
    legend(order(1 "AIPI≥0.7" 3 "Other Countries" 8 "Overperformers" 13 "Linear Fit Line [weighted pop. size]") pos(6) size(tiny)) /*///
    note("Overperformers are shown in yellow with country labels", size(tiny))*/
	
graph export "output/Figure 3B.png", replace

		
restore


****
*-LMICs/UMICs [weighted by pop size]
preserve

* Only LICs/UMICs
keep if incomelevel == "LMC" | incomelevel == "UMC"

* Create categories for population size
gen pop_category = .
replace pop_category = 1 if pop_size < 10e6  // Small population (< 10 million)
replace pop_category = 2 if pop_size >= 10e6 & pop_size < 50e6  // Medium population (10 to 50 million)
replace pop_category = 3 if pop_size >= 50e6 & pop_size < 100e6  // Large population (50 to 100 million)
replace pop_category = 4 if pop_size >= 100e6 & pop_size < 300e6  // Very large population (100 to 300 million)
replace pop_category = 5 if pop_size >= 300e6  // Yuuge population (> 300 million)


* Calculate fitted values and determine overperformers (AIPI >= 0.5 and above the fit line)
regress AIPI KH_e_scaled [aw=pop_size]
predict AIPI_hat if e(sample)
gen overperformer = (AIPI >= 0.5 & AIPI > AIPI_hat)

ttest AIPI == AIPI_hat if overperformer == 0 
ttest AIPI == AIPI_hat if overperformer == 1

* Find the range of KH_e_scaled for AIPI >= 0.5
summarize KH_e_scaled if AIPI >= 0.5
local kh_min = r(min)
local kh_max = r(max)

/*
* Create variables to define the rectangle for AIPI >= 0.7
gen y_lower = 0.5
gen y_upper = 0.64
*/

/*
*/
* Define the coordinates for the rectangle
gen x_rect = .
gen y_rect = .

* Define the four corners of the rectangle
replace x_rect = `kh_min' in 1
replace y_rect = 0.5 in 1

replace x_rect = `kh_max' in 2
replace y_rect = 0.5 in 2

replace x_rect = `kh_max' in 3
replace y_rect = 0.65 in 3

replace x_rect = `kh_min' in 4
replace y_rect = 0.65 in 4

* Close the rectangle by adding the first point again
replace x_rect = `kh_min' in 5
replace y_rect = 0.5 in 5



* Calculate the correlation coefficient (r) and R² value, rounded to two decimal places
correlate AIPI KH_e_scaled [aw=pop_size]
/*pwcorr AIPI KH_e_scaled [aw=pop_size], sig */

local r = round(r(rho), 0.01)
local r2 = string(round(e(r2), 0.001), "%9.2f")  // Convert to string with two decimal places

* Calculate the sample size
count if !missing(KH_e_scaled, AIPI)
local n = r(N)

* Scatterplot with overperformers highlighted, including R² and r in the chart
twoway ///
    (connected y_rect x_rect, mcolor(gs15) lcolor(gs15)) || ///
    (scatter AIPI KH_e_scaled if !overperformer & pop_category == 1 , mcolor(blue%60) msize(tiny) mlab(country_code) mlabsize(tiny)) || ///
    (scatter AIPI KH_e_scaled if !overperformer & pop_category == 2 , mcolor(blue%60) msize(small) mlab(country_code) mlabsize(tiny)) || ///
    (scatter AIPI KH_e_scaled if !overperformer & pop_category == 3 , mcolor(blue%60) msize(medium) mlab(country_code) mlabsize(tiny)) || ///
    (scatter AIPI KH_e_scaled if !overperformer & pop_category == 4, mcolor(blue%60) msize(large) mlab(country_code) mlabsize(tiny)) || ///
	(scatter AIPI KH_e_scaled if !overperformer & pop_category == 5, mcolor(blue%60) msize(huge) mlab(country_code) mlabsize(tiny)) || ///
    (scatter AIPI KH_e_scaled if overperformer & pop_category == 1 , mcolor(gold%60) msize(tiny) mlab(country_code) mlabsize(tiny)) || ///
    (scatter AIPI KH_e_scaled if overperformer & pop_category == 2 , mcolor(gold%60) msize(small) mlab(country_code) mlabsize(tiny)) || ///
    (scatter AIPI KH_e_scaled if overperformer & pop_category == 3 , mcolor(gold%60) msize(medium) mlab(country_code) mlabsize(tiny)) || ///
    (scatter AIPI KH_e_scaled if overperformer & pop_category == 4 , mcolor(gold%60) msize(large) mlab(country_code) mlabsize(tiny)) || ///
	(scatter AIPI KH_e_scaled if overperformer & pop_category == 5 , mcolor(gold%60) msize(huge) mlab(country_code) mlabsize(tiny)) || ///
    (lfit AIPI KH_e_scaled [aw=pop_size], lcolor(red%80)), ///
    ytitle("AI Prepardness Index (IMF, 2023)") ///
	ylabel(0.2(.1).65, angle(0)) ///
	xlabel(0(.1).7, angle(0)) ///
    xtitle("Economic Complexity Index [Trade-Research PCA] (OEC, 2021-22)") ///
    /*title("Relationship between ECI and AIPI")*/ ///
    text(0.65 0 "N = `n'" 0.60 0 "R² = `r2'" 0.55 0 "r = 0`r'", color(gs6) place(e) size(small)) ///
    legend(order(1 "AIPI≥0.5" 3 "Other LMICs/UMICs" 8 "Local overperformers" 12 "Linear Fit Line [weighted pop. size]") pos(6) size(tiny)) /*///
    note("Overperformers are shown in yellow with country labels", size(tiny))*/
	
graph export "output/Figure 4.png", replace

		
restore


****
*-LICs/LMICs [weighted by pop size]
preserve

* Only LICs/LMICs
keep if incomelevel == "LIC" | incomelevel == "LMC"


* Create categories for population size
gen pop_category = .
replace pop_category = 1 if pop_size < 10e6  // Small population (< 10 million)
replace pop_category = 2 if pop_size >= 10e6 & pop_size < 50e6  // Medium population (10 to 50 million)
replace pop_category = 3 if pop_size >= 50e6 & pop_size < 100e6  // Large population (50 to 100 million)
replace pop_category = 4 if pop_size >= 100e6 & pop_size < 300e6  // Very large population (100 to 300 million)
replace pop_category = 5 if pop_size >= 300e6  // Yuuge population (> 300 million)


* Calculate fitted values and determine overperformers (AIPI >= 0.4 and above the fit line)
regress AIPI KH_e_scaled [aw=pop_size]
predict AIPI_hat if e(sample)
gen overperformer = (AIPI >= 0.4 & AIPI > AIPI_hat)

ttest AIPI == AIPI_hat if overperformer == 0 
ttest AIPI == AIPI_hat if overperformer == 1

* Find the range of KH_e_scaled for AIPI > 0.4
summarize KH_e_scaled if AIPI >= 0.4
local kh_min = r(min)
local kh_max = r(max)

* Define the coordinates for the rectangle
gen x_rect = .
gen y_rect = .

* Define the four corners of the rectangle
replace x_rect = `kh_min' in 1
replace y_rect = 0.4 in 1

replace x_rect = `kh_max' in 2
replace y_rect = 0.4 in 2

replace x_rect = `kh_max' in 3
replace y_rect = 0.5 in 3

replace x_rect = `kh_min' in 4
replace y_rect = 0.5 in 4

* Close the rectangle by adding the first point again
replace x_rect = `kh_min' in 5
replace y_rect = 0.4 in 5


* Calculate the correlation coefficient (r) and R² value, rounded to two decimal places
correlate AIPI KH_e_scaled [aw=pop_size]
/*pwcorr AIPI KH_e_scaled [aw=pop_size], sig */

local r = string(round(r(rho), 0.01), "%9.2f")  // Convert to string with two decimal places
local r2 = string(round(e(r2), 0.001), "%9.2f")  // Convert to string with two decimal places

* Calculate the sample size
count if !missing(KH_e_scaled, AIPI)
local n = r(N)

* Scatterplot with overperformers highlighted, including R² and r in the chart
twoway ///
    (connected y_rect x_rect, mcolor(gs15) lcolor(gs15)) || ///
    (scatter AIPI KH_e_scaled if !overperformer & pop_category == 1 , mcolor(blue%60) msize(tiny) mlab(country_code) mlabsize(tiny)) || ///
    (scatter AIPI KH_e_scaled if !overperformer & pop_category == 2 , mcolor(blue%60) msize(small) mlab(country_code) mlabsize(tiny)) || ///
    (scatter AIPI KH_e_scaled if !overperformer & pop_category == 3 , mcolor(blue%60) msize(medium) mlab(country_code) mlabsize(tiny)) || ///
    (scatter AIPI KH_e_scaled if !overperformer & pop_category == 4, mcolor(blue%60) msize(large) mlab(country_code) mlabsize(tiny)) || ///
	(scatter AIPI KH_e_scaled if !overperformer & pop_category == 5, mcolor(blue%60) msize(huge) mlab(country_code) mlabsize(tiny)) || ///
    (scatter AIPI KH_e_scaled if overperformer & pop_category == 1 & country_code != "lka", mcolor(gold%60) msize(tiny) mlab(country_code) mlabsize(tiny)) || ///
    (scatter AIPI KH_e_scaled if overperformer & pop_category == 2 & country_code != "lka", mcolor(gold%60) msize(small) mlab(country_code) mlabsize(tiny)) || ///
    (scatter AIPI KH_e_scaled if overperformer & pop_category == 3 & country_code != "lka", mcolor(gold%60) msize(medium) mlab(country_code) mlabsize(tiny)) || ///
    (scatter AIPI KH_e_scaled if overperformer & pop_category == 4 & country_code != "lka", mcolor(gold%60) msize(large) mlab(country_code) mlabsize(tiny)) || ///
	(scatter AIPI KH_e_scaled if overperformer & pop_category == 5 & country_code != "lka", mcolor(gold%60) msize(huge) mlab(country_code) mlabsize(tiny)) || ///
    (scatter AIPI KH_e_scaled if country_code == "lka", mcolor(gold%60) msize(small) mlab(country_code) mlabsize(tiny) mlabposition(12)) || ///
    (lfit AIPI KH_e_scaled [aw=pop_size], lcolor(red%80)), ///
    ytitle("AI Prepardness Index (IMF, 2023)") ///
	ylabel(0.1(.1).55, angle(0)) ///
    xtitle("Economic Complexity Index [Trade-Research PCA] (OEC, 2021-22)") ///
    /*title("Relationship between ECI and AIPI")*/ ///
    text(0.55 0 "N = `n'" 0.50 0 "R² = `r2'" 0.45 0 "r = `r'", color(gs6) place(e) size(small)) ///
    legend(order(1 "AIPI≥0.4" 3 "Other LICs/LMICs" 8 "Local overperformers" 13 "Linear Fit Line [weighted pop. size]") pos(6) size(tiny)) /*///
    note("Overperformers are shown in yellow with country labels", size(tiny))*/
	
graph export "output/Figure 5.png", replace

		
restore
}

********************************************************************************
* Code to Run (Appendix) Descriptive Stat Tables
{
preserve

* Create a new variable to identify AIPI overperformers
gen AIPI_Overperformer = "No"
gen AIPI_Hat=.

regress AIPI KH_e_scaled [aw=pop_size]
predict AIPI_hat if e(sample)
replace AIPI_Hat= AIPI_hat if incomelevel == "HIC"
replace AIPI_Overperformer = "Yes (Global)" if AIPI > AIPI_hat & incomelevel == "HIC" & AIPI >= 0.7
drop AIPI_hat

regress AIPI KH_e_scaled [aw=pop_size] if incomelevel == "LMC" | incomelevel == "UMC" 
predict AIPI_hat if e(sample)
replace AIPI_Hat= AIPI_hat if incomelevel == "UMC"
replace AIPI_Overperformer = "Yes (Local)" if AIPI > KH_r & incomelevel == "UMC" & AIPI >= 0.5
drop AIPI_hat


regress AIPI KH_e_scaled [aw=pop_size] if incomelevel == "LIC" | incomelevel == "LMC" 
predict AIPI_hat if e(sample)
replace AIPI_Hat= AIPI_hat if incomelevel == "LIC" | incomelevel == "LMC"
replace AIPI_Overperformer = "Yes (Local)" if AIPI > KH_r & (incomelevel == "LIC" | incomelevel == "LMC") & AIPI >= 0.4
drop AIPI_hat

* Create the descriptive table
format KH_e_scaled AIPI AIPI_Hat  %9.3f
log using "output/Table A2.txt", text replace
list countryname regionname incomelevel KH_e_scaled AIPI AIPI_Hat AIPI_Overperformer /*if !missing(AIPI, KH_e_scaled)*/
log close

restore
}

********************************************************************************
* Map: Global Distribution of AIPI
{
clear all

shp2dta using "rawData/WB_countries_Admin0_10m", data(world) coor(worldcoord) replace genid(id) genc(c)
use world, clear


rename FORMAL_EN countryname
rename WB_A3 countrycode
drop if WB_A2=="-99" & countrycode=="USA" // Guantanamo Bay Naval Base; United States Minor Outlying Islands
drop if WB_A2=="-99" & countrycode=="FRA" // Clipperton Island
drop if countrycode=="BES" //  Caribbean Netherlands
drop if countrycode=="UMI" //  A group of small islands, atolls, and reefs that are unincorporated and mostly uninhabited territories of the United States.

replace countrycode="COD" if countrycode=="ZAR"
replace countrycode="ROU" if countrycode=="ROM"
replace countrycode="TLS" if countrycode=="TMP"

save world, replace

use "intData/aipi_eci.dta", clear
replace countrycode="TWN" if countrycode==""
merge m:1 countrycode using world
tab _merge 

spmap AIPI using worldcoord /*if id!=7*/, id(id) fcolor(Spectral) ///
legtitle(Legend: ) ///
legend(label(2 "Under 0.2") label(3 "0.2-0.3") label(4 "0.3-0.4") label(5 "0.4-0.5") label(6 "0.5-0.6") label(7 "0.6-0.7") label(8 "0.7-0.8") label(9 "0.8 and more"))  ///
note(" ""Scale 1:110,000,000.", size(*0.75)) legorder(lohi) clmethod(custom) clb(0 0.2 0.3 0.4 0.5 0.6 0.7 0.8 1)

graph export "output/Figure 1.png", replace

erase world.dta
erase worldcoord.dta

}


*stop
********************************************************************************
* Merge AIPI Pillars Together and Run Waffle/Spiderweb Charts
{
import excel "rawData/imf-dm-export-20241120_pillar1_di.xls", firstrow clear // https://www.imf.org/external/datamapper/datasets/AIPI

rename (DigitalInfrastructureIndex B) (countryname pillarI_di_index)

* Keep only individual countries
keep if !inlist(countryname, "Advanced economies", "Emerging market economies", "Asia and Pacific", "European Union", "Euro area", "Europe")

keep if !inlist(countryname, "North America", "Sub-Saharan Africa (Region)", "ASEAN-5", "Latin America and the Caribbean", "Low-income countries", "Major advanced economies (G7)", "Middle East and Central Asia", "Sub-Saharan Africa (Region) ")

drop if missing(pillarI_di_index)

* Replace non-standardized country names with standardized versions
replace countryname = "Bahamas" if countryname == "Bahamas, The"
replace countryname = "China" if countryname == "China, People's Republic of"
replace countryname = "Congo (Democratic Republic)" if countryname == "Congo, Dem. Rep. of the"
replace countryname = "Congo (Republic)" if countryname == "Congo, Republic of "
replace countryname = "Ivory Coast" if countryname == "Côte d'Ivoire"
replace countryname = "Gambia" if countryname == "Gambia, The"
replace countryname = "South Korea" if countryname == "Korea, Republic of"
replace countryname = "North Macedonia" if countryname == "North Macedonia "
replace countryname = "South Sudan" if countryname == "South Sudan, Republic of"
replace countryname = "Turkey" if countryname == "Türkiye, Republic of"

save aipi_di_temp, replace


import excel "rawData/imf-dm-export-20241120_pillar2_iei.xls", firstrow clear // https://www.imf.org/external/datamapper/datasets/AIPI

rename (InnovationandEconomicIntegrat B) (countryname pillarII_iei_index)

* Keep only individual countries
keep if !inlist(countryname, "Advanced economies", "Emerging market economies", "Asia and Pacific", "European Union", "Euro area", "Europe")

keep if !inlist(countryname, "North America", "Sub-Saharan Africa (Region)", "ASEAN-5", "Latin America and the Caribbean", "Low-income countries", "Major advanced economies (G7)", "Middle East and Central Asia", "Sub-Saharan Africa (Region) ")

drop if missing(pillarII_iei_index)

* Replace non-standardized country names with standardized versions
replace countryname = "Bahamas" if countryname == "Bahamas, The"
replace countryname = "China" if countryname == "China, People's Republic of"
replace countryname = "Congo (Democratic Republic)" if countryname == "Congo, Dem. Rep. of the"
replace countryname = "Congo (Republic)" if countryname == "Congo, Republic of "
replace countryname = "Ivory Coast" if countryname == "Côte d'Ivoire"
replace countryname = "Gambia" if countryname == "Gambia, The"
replace countryname = "South Korea" if countryname == "Korea, Republic of"
replace countryname = "North Macedonia" if countryname == "North Macedonia "
replace countryname = "South Sudan" if countryname == "South Sudan, Republic of"
replace countryname = "Turkey" if countryname == "Türkiye, Republic of"

save aipi_iei_temp, replace


import excel "rawData/imf-dm-export-20241120_pillar3_hclmp.xls", firstrow clear // https://www.imf.org/external/datamapper/datasets/AIPI

rename (HumanCapitalandLaborMarketP B) (countryname pillarIII_hclmp_index)

* Keep only individual countries
keep if !inlist(countryname, "Advanced economies", "Emerging market economies", "Asia and Pacific", "European Union", "Euro area", "Europe")

keep if !inlist(countryname, "North America", "Sub-Saharan Africa (Region)", "ASEAN-5", "Latin America and the Caribbean", "Low-income countries", "Major advanced economies (G7)", "Middle East and Central Asia", "Sub-Saharan Africa (Region) ")

drop if missing(pillarIII_hclmp_index)

* Replace non-standardized country names with standardized versions
replace countryname = "Bahamas" if countryname == "Bahamas, The"
replace countryname = "China" if countryname == "China, People's Republic of"
replace countryname = "Congo (Democratic Republic)" if countryname == "Congo, Dem. Rep. of the"
replace countryname = "Congo (Republic)" if countryname == "Congo, Republic of "
replace countryname = "Ivory Coast" if countryname == "Côte d'Ivoire"
replace countryname = "Gambia" if countryname == "Gambia, The"
replace countryname = "South Korea" if countryname == "Korea, Republic of"
replace countryname = "North Macedonia" if countryname == "North Macedonia "
replace countryname = "South Sudan" if countryname == "South Sudan, Republic of"
replace countryname = "Turkey" if countryname == "Türkiye, Republic of"

save aipi_hclmp_temp, replace


import excel "rawData/imf-dm-export-20241120_pillar4_re.xls", firstrow clear // https://www.imf.org/external/datamapper/datasets/AIPI

rename (RegulationandEthicsIndex B) (countryname pillarIV_re_index)


* Keep only individual countries
keep if !inlist(countryname, "Advanced economies", "Emerging market economies", "Asia and Pacific", "European Union", "Euro area", "Europe")

keep if !inlist(countryname, "North America", "Sub-Saharan Africa (Region)", "ASEAN-5", "Latin America and the Caribbean", "Low-income countries", "Major advanced economies (G7)", "Middle East and Central Asia", "Sub-Saharan Africa (Region) ")

drop if missing(pillarIV_re_index)

* Replace non-standardized country names with standardized versions
replace countryname = "Bahamas" if countryname == "Bahamas, The"
replace countryname = "China" if countryname == "China, People's Republic of"
replace countryname = "Congo (Democratic Republic)" if countryname == "Congo, Dem. Rep. of the"
replace countryname = "Congo (Republic)" if countryname == "Congo, Republic of "
replace countryname = "Ivory Coast" if countryname == "Côte d'Ivoire"
replace countryname = "Gambia" if countryname == "Gambia, The"
replace countryname = "South Korea" if countryname == "Korea, Republic of"
replace countryname = "North Macedonia" if countryname == "North Macedonia "
replace countryname = "South Sudan" if countryname == "South Sudan, Republic of"
replace countryname = "Turkey" if countryname == "Türkiye, Republic of"

save aipi_re_temp, replace


use aipi_di_temp

merge 1:1 countryname using aipi_iei_temp
drop _merge

merge 1:1 countryname using aipi_hclmp_temp
drop _merge

merge 1:1 countryname using aipi_re_temp
drop _merge



save "intData/ai_pillars.dta", replace
erase aipi_di_temp.dta
erase aipi_iei_temp.dta
erase aipi_hclmp_temp.dta
erase aipi_re_temp.dta


keep countryname pillarI_di_index
rename pillarI_di_index index_value
generate pillar = "Digital Infr."
save pillarI_data, replace


use "intData/ai_pillars.dta", clear
keep countryname pillarII_iei_index
rename pillarII_iei_index index_value
generate pillar = "Innov. & Integr."
save pillarII_data, replace


use "intData/ai_pillars.dta", clear
keep countryname pillarIII_hclmp_index
rename pillarIII_hclmp_index index_value
generate pillar = "Human K. & Labor Mkt"
save pillarIII_data, replace


use "intData/ai_pillars.dta", clear
keep countryname pillarIV_re_index
rename pillarIV_re_index index_value
generate pillar = "Reg. & Ethics"
save pillarIV_data, replace


use pillarI_data
append using pillarII_data
append using pillarIII_data
append using pillarIV_data

sort countryname pillar
order countryname pillar


save "intData/ai_pillars.dta", replace

merge m:1 countryname using "intData/aipi_eci.dta"
drop if _merge==2
keep if KH_e_scaled!=. // to have a consistent sample with scatters
drop regionname AIPI ECI_Trade ECI_Tech ECI_Res KH_e KH_r KH_r_scaled KH_e_scaled _merge

erase pillarI_data.dta
erase pillarII_data.dta
erase pillarIII_data.dta
erase pillarIV_data.dta



* Waffle decomposition
{
preserve

gen group1="1" if countrycode=="AUS" | countrycode=="HKG" | countrycode=="JPN" | countrycode=="KOR" | countrycode=="NZL" | countrycode=="SGP" | countrycode=="DNK" | countrycode=="FIN" | countrycode=="NLD" | countrycode=="NOR"
replace group1="2" if countrycode=="ALB" | countrycode=="CHN" | countrycode=="CRI" | countrycode=="IDN" | countrycode=="KAZ" | countrycode=="MYS" | countrycode=="UKR" 
replace group1="3" if countrycode=="GHA" | countrycode=="IND" | countrycode=="LKA" | countrycode=="MAR" | countrycode=="RWA" | countrycode=="TUN" | countrycode=="VNM" 


collapse (mean) index_value [aw= pop_size], by(group1 pillar)
drop if group1==""
encode group1, gen(group_code)

drop group1
reshape wide index_value, i(pillar) j(group_code)

label var index_value1 "Overperformers 3/3 (HICs)"
label var index_value2 "Overperformers 2/3 (UMCs)"
label var index_value3 "Overperformers 1/3 (LIC/LMICs)"


waffle index_value1 index_value2 index_value3, over(pillar) palette(twilight) msym(Oh triangle Dh +) mlwid(0.5 0.2 0.5 0.5) rowdots(10) msize(1.1) format(%6.2f) percent note("")

graph export "output/Figure 6.png", replace width(1200)


*waffle index_value3 index_value2 index_value1, over(pillar) palette(twilight) msym(Oh triangle Dh +) mlwid(0.5 0.2 0.5 0.5) rowdots(10) msize(1.1) format(%6.2f) note("")



/*

pillar	index_value1	index_value2	index_value3
Digital Infr.	.18167615	.17667797	.10747342
Human K. & Labor Mkt	.16988816	.14715612	.12329766
Innov. & Integr.	.17868251	.1390609	.11003341
Reg. & Ethics	.2052978	.1500776	.14678097

			
Digital Infr.	24.7%	28.8%	22.0%
Human K. & Labor Mkt	23.1%	24.0%	25.3%
Innov. & Integr.	24.3%	22.7%	22.6%
Reg. & Ethics	27.9%	24.5%	30.1%




=> storyline: 

In low-income and lower-middle-income overperformers (LICs/LMICs), regulation and ethics emerge as the most significant driver of AI preparedness, accounting for 30.1% (Indian and SSA models) of the emphasis. This highlights the critical role of governance in building trust and establishing frameworks for AI deployment, even amidst considerable structural challenges. Following closely is the focus on human capital and labor markets (25.3%, Indian model), reflecting the pressing need to develop skills and prepare the workforce for a technology-driven future. However, digital infrastructure (22.0%) and innovation and integration (22.6%) are less emphasized, likely constrained by limited fiscal resources and technological investment capacity.

For upper-middle-income overperformers (UMICs), the emphasis shifts, with digital infrastructure taking the lead (28.8%, Chinese model), reflecting the growing technological capabilities and infrastructure investments of these nations. Regulation and ethics remain essential at 24.5% (Malaysian model), underscoring the importance of robust governance in fostering AI readiness. Human capital and labor markets (24.0%, Malaysian and Kazakh model) also maintain a strong focus as these nations work to enhance workforce preparedness. Innovation and integration, however, remain the least prioritized pillar at 22.7%, possibly due to structural constraints, though this requires careful interpretation. For instance, China's status as a leader in AI technology production—comparable to that of the United States—may be underestimated in this metric due to the "economic integration" component, which accounts for tariff and non-tariff barriers, as well as restrictions on capital and labor movement. This underscores that robust domestic innovation can thrive even with lower scores in economic integration measures.


High-income overperformers (HICs) present a more balanced profile, with regulation and ethics taking the lead at 27.9% (Singapore and North Europe model), emphasizing the importance of governance frameworks in managing advanced AI integration. Digital infrastructure follows at 24.7% (Singapore model), reflecting the continuous effort to maintain a technological edge. Innovation and integration (24.3%) gain slightly more prominence compared to lower-income groups, while human capital and labor markets (23.1%) play a supporting role, as these countries already benefit from well-established systems for education and workforce development.

Across all income levels, regulation and ethics consistently top the list, but the relative emphasis on digital infrastructure, workforce development, and innovation adapts to the specific needs and capacities of each economic group.



*/

restore
}

* Spider HICs [SGP; Northern Europe]
{

/*
preserve

gen group1="Overperformers (HICs)" if countrycode=="AUS" | countrycode=="HKG" | countrycode=="JPN" | countrycode=="KOR" | countrycode=="NZL" | countrycode=="SGP" | countrycode=="DNK" | countrycode=="FIN" | countrycode=="NLD" | countrycode=="NOR"
replace group1="Other Non-ov. (ii) ECA-NAC HICs" if group1=="" & incomelevel=="HIC" & regioncode=="ECS" | group1=="" & incomelevel=="HIC" & regioncode=="NAC"
replace group1="Other Non-ov. (i) HICs" if group1=="" & incomelevel=="HIC"


collapse (mean) index_value [aw= pop_size], by(group1 pillar)

drop if group1==""
spider index_value, by(pillar) over(group1) ra(0(0.05)0.25) palette(GrandBudapest1) sc(black) legcol(1) smooth(0.2) alpha(5) wrap(5) displacelab(20) displacespike(10) rotatelab rot(30) lp(dot dot solid) format(%6.2f)

restore
*/

preserve

gen group1="Overperformer (SGP)" if countrycode=="SGP" 
replace group1="Other overperformers (HICs)" if countrycode=="AUS" | countrycode=="HKG" | countrycode=="JPN" | countrycode=="KOR" | countrycode=="NZL" |  countrycode=="DNK" | countrycode=="FIN" | countrycode=="NLD" | countrycode=="NOR"
replace group1="Other Non-ov. (ii) ECA-NAC HICs" if group1=="" & incomelevel=="HIC" & regioncode=="ECS" | group1=="" & incomelevel=="HIC" & regioncode=="NAC"
replace group1="Other Non-ov. (i) HICs" if group1=="" & incomelevel=="HIC" 


collapse (mean) index_value [aw= pop_size], by(group1 pillar)

drop if group=="Other overperformers (HICs)" | group1==""
spider index_value, by(pillar) over(group1) ra(0(0.05)0.25) palette(GrandBudapest1) sc(black) legcol(1) smooth(0.2) alpha(5) wrap(5) displacelab(20) displacespike(10) rotatelab rot(30) lp(dot dot solid) format(%6.2f)
graph export "output/Figure 7a.png", replace width(1200)

restore


preserve

gen group1="Overperformers (Northern Eur.)" if countrycode=="DNK" | countrycode=="FIN" | countrycode=="NOR"
replace group1="Other overperformers (HICs)" if countrycode=="AUS" | countrycode=="HKG" | countrycode=="JPN" | countrycode=="KOR" | countrycode=="NZL" | countrycode=="SGP"
replace group1="Other Non-ov. (ii) ECA-NAC HICs" if group1=="" & incomelevel=="HIC" & regioncode=="ECS" | group1=="" & incomelevel=="HIC" & regioncode=="NAC"
replace group1="Other Non-ov. (i) HICs" if group1=="" & incomelevel=="HIC"


collapse (mean) index_value [aw= pop_size], by(group1 pillar)

drop if group=="Other overperformers (HICs)" | group1==""
spider index_value, by(pillar) over(group1) ra(0(0.05)0.25) palette(GrandBudapest1) sc(black) legcol(1) smooth(0.2) alpha(5) wrap(5) displacelab(20) displacespike(10) rotatelab rot(30) lp(dot dot solid) format(%6.2f)
graph export "output/Figure 7b.png", replace width(1200)


restore


}

* Spider UMICs [CHN, MYS, KAZ]
{
/*
preserve

gen group2="Overperformers (UMICs)" if countrycode=="ALB" | countrycode=="CHN" | countrycode=="CRI" | countrycode=="IDN" | countrycode=="KAZ" | countrycode=="MYS" | countrycode=="UKR" 
replace group2="Other non-overperformers (ii) UMICs" if group2=="" & incomelevel=="UMC" 
replace group2="Other non-overperformers (i) LMICs" if group2=="" & incomelevel=="LMC"

collapse (mean) index_value [aw= pop_size], by(group2 pillar)

drop if group2==""
spider index_value, by(pillar) over(group2) ra(0(0.05)0.25) palette(GrandBudapest1) sc(black) legcol(1) smooth(0.2) alpha(5) wrap(5) displacelab(20) displacespike(10) rotatelab rot(30) lp(dot dot solid) format(%6.2f)

restore
*/

preserve

gen group2="Overperformer (CHN)" if countrycode=="CHN"
replace group2="Oher overperformers (UMICs)" if countrycode=="ALB" | countrycode=="CRI" | countrycode=="IDN" | countrycode=="KAZ" | countrycode=="MYS" | countrycode=="UKR" 
replace group2="Other non-overperformers (ii) UMICs" if group2=="" & incomelevel=="UMC" 
replace group2="Other non-overperformers (i) LMICs" if group2=="" & incomelevel=="LMC"

collapse (mean) index_value [aw= pop_size], by(group2 pillar)

drop if group2=="Oher overperformers (UMICs)" | group2==""
spider index_value, by(pillar) over(group2) ra(0(0.05)0.25) palette(GrandBudapest1) sc(black) legcol(1) smooth(0.2) alpha(5) wrap(5) displacelab(20) displacespike(10) rotatelab rot(30) lp(dot dot solid) format(%6.2f)
graph export "output/Figure 8a.png", replace width(1200)

restore


preserve

gen group2="Overperformer (MYS)" if countrycode=="MYS"
replace group2="Oher overperformers (UMCs)" if countrycode=="ALB" | countrycode=="CHN" | countrycode=="CRI" | countrycode=="IDN" | countrycode=="KAZ" | countrycode=="UKR" 
replace group2="Other non-overperformers (ii) UMICs" if group2=="" & incomelevel=="UMC" 
replace group2="Other non-overperformers (i) LMICs" if group2=="" & incomelevel=="LMC"

collapse (mean) index_value [aw= pop_size], by(group2 pillar)

drop if group2=="Oher overperformers (UMCs)" | group2==""
spider index_value, by(pillar) over(group2) ra(0(0.05)0.25) palette(GrandBudapest1) sc(black) legcol(1) smooth(0.2) alpha(5) wrap(5) displacelab(20) displacespike(10) rotatelab rot(30) lp(dot dot solid) format(%6.2f)
graph export "output/Figure 8b.png", replace width(1200)

restore


preserve

gen group2="Overperformer (KAZ)" if countrycode=="KAZ"
replace group2="Oher overperformers (UMCs)" if countrycode=="ALB" | countrycode=="CHN" | countrycode=="CRI" | countrycode=="IDN" | countrycode=="MYS" | countrycode=="UKR" 
replace group2="Other non-overperformers (ii) UMICs" if group2=="" & incomelevel=="UMC" 
replace group2="Other non-overperformers (i) LMICs" if group2=="" & incomelevel=="LMC"

collapse (mean) index_value [aw= pop_size], by(group2 pillar)

drop if group2=="Oher overperformers (UMCs)" | group2==""
spider index_value, by(pillar) over(group2) ra(0(0.05)0.25) palette(GrandBudapest1) sc(black) legcol(1) smooth(0.2) alpha(5) wrap(5) displacelab(20) displacespike(10) rotatelab rot(30) lp(dot dot solid) format(%6.2f)
graph export "output/Figure 8c.png", replace width(1200)


restore



}

* Spider LICs/LMICs [IND; Africa]
{
/*
preserve

gen group3="Overperformers (LICs/LMICs)" if countrycode=="GHA" | countrycode=="IND" | countrycode=="LKA" | countrycode=="MAR" | countrycode=="RWA" | countrycode=="TUN" | countrycode=="VNM" 
replace group3="Other non-overperformers (ii) LMICs" if group3=="" & incomelevel=="LMC" 
replace group3="Other non-overperformers (i) LICs" if group3=="" & incomelevel=="LIC" 

collapse (mean) index_value [aw= pop_size], by(group3 pillar)

drop if group3==""
spider index_value, by(pillar) over(group3) ra(0(0.05)0.25) palette(GrandBudapest1) sc(black) legcol(1) smooth(0.2) alpha(5) wrap(5) displacelab(20) displacespike(10) rotatelab rot(30) lp(dot dot solid) format(%6.2f)

restore
*/

preserve

gen group3="Overperformer (IND)" if countrycode=="IND"
replace group3="Oher overperformers (LICs/LMICs)" if countrycode=="GHA" | countrycode=="LKA" | countrycode=="MAR" | countrycode=="RWA" | countrycode=="TUN" | countrycode=="VNM" 
replace group3="Other non-overperformers (ii) LMICs" if group3=="" & incomelevel=="LMC" 
replace group3="Other non-overperformers (i) LICs" if group3=="" & incomelevel=="LIC" 

collapse (mean) index_value [aw= pop_size], by(group3 pillar)

drop if group3=="Oher overperformers (LICs/LMICs)" | group3==""
spider index_value, by(pillar) over(group3) ra(0(0.05)0.25) palette(GrandBudapest1) sc(black) legcol(1) smooth(0.2) alpha(5) wrap(5) displacelab(20) displacespike(10) rotatelab rot(30) lp(dot dot solid) format(%6.2f)
graph export "output/Figure 9a.png", replace width(1200)


restore


preserve

gen group3="Overperformer (SSA: GHA, RWA)" if countrycode=="GHA" | countrycode=="RWA"
replace group3="Oher overperformers (LICs/LMICs)" if countrycode=="IND" | countrycode=="LKA" | countrycode=="MAR" | countrycode=="TUN" | countrycode=="VNM" 
replace group3="Other non-overperformers (ii) LMICs" if group3=="" & incomelevel=="LMC" 
replace group3="Other non-overperformers (i) LICs" if group3=="" & incomelevel=="LIC" 

collapse (mean) index_value [aw= pop_size], by(group3 pillar)

drop if group3=="Oher overperformers (LICs/LMICs)" | group3==""
spider index_value, by(pillar) over(group3) ra(0(0.05)0.25) palette(GrandBudapest1) sc(black) legcol(1) smooth(0.2) alpha(5) wrap(5) displacelab(20) displacespike(10) rotatelab rot(30) lp(dot dot solid) format(%6.2f)
graph export "output/Figure 9b.png", replace width(1200)

restore


}

* Spider SSA
{
preserve

gen group4="Overperformers (SSA: GHA, RWA)" if countrycode=="GHA" | countrycode=="RWA" 
replace group4="Non-overperformers SSA (LICs)" if group4=="" & regioncode=="SSF" & incomelevel=="LIC"
replace group4="Non-overperformers SSA (Others)" if group4=="" & regioncode=="SSF" 


collapse (mean) index_value [aw= pop_size], by(group4 pillar)

drop if group4==""
spider index_value, by(pillar) over(group4) ra(0(0.05)0.25) palette(GrandBudapest1) sc(black) legcol(1) smooth(0.2) alpha(5) wrap(5) displacelab(20) displacespike(10) rotatelab rot(30) lp(dot dot solid) format(%6.2f)

restore


}


}


