# install.packages(c("haven", "BMS", "foreign", "xtable", "LowRankQP", "here"), dependencies = TRUE, quiet = TRUE)
# 
# library(foreign)
# library(xtable)
# library(LowRankQP)
# library(haven)
# library(BMS)
# library(foreign)
# library(here)

renv::init()

rm(list=ls())

set.seed(12345)

burn_       = 10e6
iter_       = 30e6
gprior      = "hyper=UIP"
modelprior  = "random"
order_PIP   = F
separator   = ","



data_bma_AI = read_dta(here("intData","data_bma_AI.dta"))
# The use of slash / instead of backslash \ is necessary here

data_bma_AI <- as.data.frame(data_bma_AI)
# data_bma_AI <- data_all[complete.cases(data_bma_AI), ]

BMA  = bms(data_bma_AI, burn=burn_, iter=iter_, g=gprior, mprior=modelprior, nmodel=5000, mcmc="bd", user.int=FALSE)


BMA_res<-coef(BMA, order.by.pip =T, exact=T,include.constant = T)
write.csv(BMA_res,here("output", "BMA_1.csv"))
# The use of slash / instead of backslash \ is necessary here

png(here("output","Figure 2.png"), width = 1600, height = 1200)
image(BMA, cex=0.7, xlab="", main="") 
dev.off()


mydata <- read.dta(here("intData","data_fma_AI.dta"), convert.dates=TRUE, convert.factors=TRUE, missing.type=TRUE, convert.underscore=TRUE, warn.missing.labels=TRUE)
# change path file here [remplacer les slash par des antislash]


# colnames(mydata)  <- c("AiPI", "LIFE060", "YRSOPEN", "REVCOUP", "CONFUC", "SIZE60", "LAAM", "H60", "EAST")
colnames(mydata)  <- c("AiPI", "LIFE060", "YRSOPEN", "REVCOUP", "CONFUC", "SIZE60", "LAAM", "H60", "EAST", "POP60", "ABSLATIT", "TROPICAR", "PI6090", "CATH00", "SOCIALIST", "EUROPE")



x.data <- mydata[,-1]
const_<-c(1)
x.data <-cbind(const_,x.data)


x <- sapply(1:ncol(x.data),function(i){x.data[,i]/max(x.data[,i])})   
scale.vector <- as.matrix(sapply(1:ncol(x.data),function(i){max(x.data[,i])}))        
Y <- as.matrix(mydata[,1])
output.colnames <- colnames(x.data)
full.fit <- lm(Y~x-1)
beta.full <- as.matrix(coef(full.fit))
M <- k <- ncol(x)
n <- nrow(x)
beta <- matrix(0,k,M)
e <- matrix(0,n,M)
K_vector <- matrix(c(1:M))
var.matrix <- matrix(0,k,M)
bias.sq <- matrix(0,k,M) 



# MMA Estimator using orthogonalization

for(i in 1:M)
{
  X <- as.matrix(x[,1:i])
  ortho <- eigen(t(X)%*%X)
  Q <- ortho$vectors ; lambda <- ortho$values 
  x.tilda <- X%*%Q%*%(diag(lambda^-0.5,i,i))
  beta.star <- t(x.tilda)%*%Y
  beta.hat <- Q%*%diag(lambda^-0.5,i,i)%*%beta.star
  beta[1:i,i] <- beta.hat
  e[,i] <- Y-x.tilda%*%as.matrix(beta.star)
  bias.sq[,i] <- (beta[,i]-beta.full)^2
  var.matrix.star <- diag(as.numeric(((t(e[,i])%*%e[,i])/(n-i))),i,i)
  var.matrix.hat <- var.matrix.star%*%(Q%*%diag(lambda^-1,i,i)%*%t(Q))
  var.matrix[1:i,i] <- diag(var.matrix.hat)
  var.matrix[,i] <- var.matrix[,i]+ bias.sq[,i]
} 

e_k <- e[,M]
sigma_hat <- as.numeric((t(e_k)%*%e_k)/(n-M))
G <- t(e)%*%e
a <- ((sigma_hat)^2)*K_vector
A <- matrix(1,1,M)
b <- matrix(1,1,1)
u <- matrix(1,M,1)
optim <- LowRankQP(Vmat=G,dvec=a,Amat=A,bvec=b,uvec=u,method="LU",verbose=FALSE)
weights <- as.matrix(optim$alpha)
beta.scaled <- beta%*%weights
final.beta <- beta.scaled/scale.vector
std.scaled <- sqrt(var.matrix)%*%weights
final.std <- std.scaled/scale.vector
results.reduced <- as.matrix(cbind(final.beta,final.std))
rownames(results.reduced) <- output.colnames; colnames(results.reduced) <- c("Coefficient", "Sd. Err")
MMA.fls <- round(results.reduced,4)
MMA.fls <- data.frame(MMA.fls)
t <- as.data.frame(MMA.fls$Coefficient/MMA.fls$Sd..Err)
MMA.fls$pv <-round( (1-apply(as.data.frame(apply(t,1,abs)), 1, pnorm))*2,3)
MMA.fls$names <- rownames(MMA.fls)
names <- c(colnames(mydata))
names <- c(names,"const_")
MMA.fls <- MMA.fls[match(names, MMA.fls$names),]
MMA.fls$names <- NULL
MMA.fls



xtable(MMA.fls,digits=c(0,3,3,3))

separator   = ";"
write.csv(MMA.fls,here("output", "FMA_1.csv"))

# change path file here [remplacer les slash par des antislash]
